@@ -1,12 +1,14 @@
 import pygame
+from PIL import Image
+import os
 from math import radians, sin, cos, atan2, degrees, sqrt
 from . import game
 from . import loaders
 from . import rect
 from . import spellcheck
+import operator
 from random import randint
 
-
 ANCHORS = {
     'x': {
         'left': 0.0,
@@ -26,6 +28,7 @@ ANCHORS = {
 def calculate_anchor(value, dim, total):
     if isinstance(value, str):
         try:
+            # print(f'total:{total * ANCHORS[dim][value]}')
             return total * ANCHORS[dim][value]
         except KeyError:
             raise ValueError(
@@ -77,18 +80,21 @@ class Actor:
 
     _anchor = _anchor_value = (0, 0)
     _angle = 0.0
-    def __init__(self, image, pos=POS_TOPLEFT,Size = 100,anchor=ANCHOR_CENTER, **kwargs):
+
+    def __init__(self, image, pos=POS_TOPLEFT, Size=100, anchor=ANCHOR_CENTER, **kwargs):
         self._handle_unexpected_kwargs(kwargs)
         self.__dict__["_rect"] = rect.ZRect((0, 0), (0, 0))
         # Initialise it at (0, 0) for size (0, 0).
         # We'll move it to the right place and resize it later
+        self.flip = True
         self._size = Size
+        self._group = []
         self.image = image
         self._init_position(pos, anchor, **kwargs)
 
     def __getattr__(self, attr):
         # print(attr)
-        if attr in self.__class__.DELEGATED_ATTRIBUTES :
+        if attr in self.__class__.DELEGATED_ATTRIBUTES:
             return getattr(self._rect, attr)
         else:
             return object.__getattribute__(self, attr)
@@ -152,9 +158,13 @@ class Actor:
         self._calc_anchor()
 
     def _calc_anchor(self):
+        # 计算锚点
+        # print(self._anchor_value)
         ax, ay = self._anchor_value
         # print(f"ax:{ax},ay:{ay}")
+        # print(f'self.width:{self.width},self.height:{self.height}')
         ow, oh = self._orig_surf.get_size()
+        # print(f"ow:{ow},oh:{oh}")
         ax = calculate_anchor(ax, 'x', ow)
         ay = calculate_anchor(ay, 'y', oh)
         self._untransformed_anchor = ax, ay
@@ -170,13 +180,14 @@ class Actor:
     @angle.setter
     def angle(self, angle):
         self._angle = angle
-        self._surf = pygame.transform.rotate(self._orig_surf, angle)
-        p = self.pos
-        self.width, self.height = self._surf.get_size()
-        w, h = self._orig_surf.get_size()
-        ax, ay = self._untransformed_anchor
-        self._anchor = transform_anchor(ax, ay, w, h, angle)
-        self.pos = p
+        if self.flip:
+            self._surf = pygame.transform.rotate(self._orig_surf, angle)
+            p = self.pos
+            self.width, self.height = self._surf.get_size()
+            w, h = self._orig_surf.get_size()
+            ax, ay = self._untransformed_anchor
+            self._anchor = transform_anchor(ax, ay, w, h, angle)
+            self.pos = p
 
     @property
     def pos(self):
@@ -218,14 +229,15 @@ class Actor:
         self._orig_surf = self._surf = loaders.images.load(image)
         self._w, self._h = self._surf.get_size()
         self._orig_surf = self._surf = pygame.transform.scale(self._surf, (
-        int(self._w * self._size / 100), int(self._h * self._size / 100)))
+            int(self._w * self._size / 100), int(self._h * self._size / 100))).convert_alpha()
         self._w, self._h = self._surf.get_size()
         self._update_pos()
+        # self.angle = p
 
     def _update_pos(self):
-        p = self.pos
-        self.width, self.height = self._surf.get_size()
-        self._calc_anchor()
+        p = self.pos  # 保存坐标
+        self.width, self.height = self._surf.get_size()  # 获得宽\高
+        self._calc_anchor()  # 计算锚点
         self.pos = p
 
     def draw(self):
@@ -239,7 +251,7 @@ class Actor:
             tx, ty = target
         myx, myy = self.pos
         dx = tx - myx
-        dy = myy - ty   # y axis is inverted from mathematical y in Pygame
+        dy = myy - ty  # y axis is inverted from mathematical y in Pygame
         return degrees(atan2(dy, dx))
 
     def distance_to(self, target):
@@ -252,6 +264,7 @@ class Actor:
         dx = tx - myx
         dy = ty - myy
         return sqrt(dx * dx + dy * dy)
+
     # yt_zxx升级
     def collidepoint(self, *args):
         if len(args) == 1:
@@ -259,17 +272,17 @@ class Actor:
         else:
             x, y = args
         return (
-            self._rect.x <= x < (self._rect.x + self._rect.w) and
-            self._rect.y <= y < (self._rect.y + self._rect.h)
+                self._rect.x <= x < (self._rect.x + self._rect.w) and
+                self._rect.y <= y < (self._rect.y + self._rect.h)
         )
 
     def colliderect(self, other):
         rect = other._rect
         return (
-            self._rect.x < rect.x + rect.w and
-            self._rect.y < rect.y + rect.h and
-            self._rect.x + self._rect.w > rect.x and
-            self._rect.y + self._rect.h > rect.y
+                self._rect.x < rect.x + rect.w and
+                self._rect.y < rect.y + rect.h and
+                self._rect.x + self._rect.w > rect.x and
+                self._rect.y + self._rect.h > rect.y
         )
 
     def collidelist(self, others):
@@ -290,7 +303,8 @@ class Actor:
     def collidedictall(self, dict, use_values=True):
         val = operator.itemgetter(1 if use_values else 0)
         return [i for i in dict.items() if self.colliderect(val(i))]
-    def collidemask(self,others):
+
+    def collidemask(self, others):
         # print(self._rect)
         xoffset = others._rect[0] - self._rect[0]
         yoffset = others._rect[1] - self._rect[1]
@@ -303,13 +317,14 @@ class Actor:
         except AttributeError:
             rightmask = pygame.mask.from_surface(others._surf)
         return leftmask.overlap(rightmask, (int(xoffset), int(yoffset)))
-        # return collide_mask(self,others)
-    def move(self,steps):
-        # print(-radians(self.angle))
-        self.x -= steps*sin(radians(self.angle))
-        self.y -= steps*cos(radians(self.angle))
-    def face_to(self,target):
+
+    def move(self, steps):
+        self.x -= steps * sin(radians(self.angle))
+        self.y -= steps * cos(radians(self.angle))
+
+    def face_to(self, target):
         self.angle = self.angle_to(target) - 90
+
     def in_the_edge(self):
         self._bounds = game.screen.bounds()
         if self.x > self._bounds[2]:
@@ -320,21 +335,42 @@ class Actor:
             self.y = self._bounds[3]
         if self.y < 0:
             self.y = 0
+
     def out_of_edge(self):
         self._bounds = game.screen.bounds()
-        return not(0-self._w < self.x < self._bounds[2]+self._w and 0-self._h < self.y < self._bounds[3]+self._h)
+        return not (0 - self._w < self.x < self._bounds[2] + self._w and 0 - self._h < self.y < self._bounds[
+            3] + self._h)
+
     @property
     def Size(self):
         return self._size
+
     @Size.setter
-    def Size(self,new_size):
-        self._w,self._h = self._surf.get_size()
-        self._orig_surf = self._surf = pygame.transform.scale(self._surf,(int(self._w*new_size/100),int(self._h*new_size/100)))
-        self._update_pos()
+    def Size(self, new_size):
         self._size = new_size
+        p = self.angle
+        self.angle = 0
+        w, h = self._orig_surf.get_size()
+        self._orig_surf = self._surf = pygame.transform.scale(self._surf,
+                                                              (int(w * self._size / 100),
+                                                               int(h * self._size / 100))).convert_alpha()
+        self._w, self._h = self._surf.get_size()
+        self._update_pos()
+        self.angle = p
+
+    def destroy(self):
+        for group in self._group:
+            group.remove(self)
+
     def yt(self):
         print("没想到吧!,我就是升级那个曾老师")
+
+
 class Group(list):
+    def append(self, __object: Actor) -> None:
+        super().append(__object)
+        __object._group.append(self)
+
     def draw(self):
         for i in self:
             i.draw()
\ No newline at end of file
