@@ -1,6 +1,7 @@
 Najia_map = [
     [('costume2.png',(240,322))],
     [('costume4',(200, 273)),('costume3',(486.0, 177.0)),('costume1',(298.0, 106.5)),('costume2.png',(240,322))],
+    [('costume1',(174.0, 224.0)),('costume1',(345.0, 110.0)),('costume2.png',(240,322))],
     [('costume7.png',(240,355)),('costume7.png',(240,31)),('costume5.png',(197,330)),('costume5.png',(324,275)),('costume6.png',(475,245))],
     [('costume7.png',(535,355)),('costume7.png',(240,31)),('costume6.png',(38,292))],
     [('costume2.png',(240,322)),('costume8',(200,200)),('costume8',(200,65)),('costume8',(115,128)),('costume3',(422,189))],
@@ -8,6 +9,7 @@ Najia_map = [
 Najia_trap = [
     [('trap2',(140.0, 266.0)),('trap2',(245.0, 266.0)),('trap2',(357.0, 266.0))],
     [('trap2',(298.0, 75.0)),('trap2',(222.0, 192.0)),('trap2',(421.0, 31.0))],
+    [('trap2',(392.0, 77.0)),('trap2',(367.0, 77.0)),('trap2',(281.0, 265.0)),('trap2',(312.0, 265.0)),('trap2',(343.0, 265.0)),('trap2',(374.0, 265.0)),('trap2',(405.0, 265.0))],
     [('trap1',(325.0, 303.0)),],
     [('trap1',(186.0, 346.0)),],
     [('trap2',(403.0, 45.0)),('trap2',(263.0, 266.0)),('trap2',(314.0, 266.0))],
